TriposFirmwareUpdatePresentation class

Annotations

Constructors

TriposFirmwareUpdatePresentation({required FirmwareUpdateEvent event, required String title, required String message, required bool isBlocking, double? progressPercent, bool isDeterminate = false, bool isSuccess = false, bool isFailure = false})
const

Properties

event FirmwareUpdateEvent
final
hashCode int
The hash code for this object.
no setterinherited
isBlocking bool
final
isDeterminate bool
final
isFailure bool
final
isSuccess bool
final
message String
final
progressPercent double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited