TriposFirmwareUpdateUiConfiguration class

Annotations

Constructors

TriposFirmwareUpdateUiConfiguration({bool automaticPresentationEnabled = true, TriposFirmwareUpdateOverlayBuilder? overlayBuilder, Duration successDismissDelay = const Duration(milliseconds: 900), Duration failureDismissDelay = const Duration(milliseconds: 1400)})
const

Properties

automaticPresentationEnabled bool
final
failureDismissDelay Duration
final
hashCode int
The hash code for this object.
no setterinherited
overlayBuilder TriposFirmwareUpdateOverlayBuilder?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successDismissDelay Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited