connectionType property
Transport used to connect to the reader.
USB is currently supported on Android for Moby 5500 only.
Implementation
final DeviceConnectionType connectionType;
Transport used to connect to the reader.
USB is currently supported on Android for Moby 5500 only.
final DeviceConnectionType connectionType;