TransactionConfiguration class

Transaction configuration for payment settings

Constructors

TransactionConfiguration({bool emvAllowed = true, bool tipAllowed = true, bool tipEntryAllowed = true, TipSelectionType tipSelectionType = TipSelectionType.amount, List<double> tipOptions = const [1.0, 2.0, 3.0], bool debitAllowed = true, bool cashbackAllowed = true, bool cashbackEntryAllowed = true, int cashbackEntryIncrement = 5, int cashbackEntryMaximum = 100, List<double> cashbackOptions = const [5.0, 10.0, 15.0], bool giftCardAllowed = true, bool quickChipAllowed = true, bool amountConfirmationEnabled = true, bool duplicateTransactionsAllowed = true, bool partialApprovalAllowed = false, bool feeAssistEnabled = false, bool proceedWithoutSurchargeOnError = false, bool shouldConfirmSurchargeAmount = false, CurrencyCode currencyCode = CurrencyCode.usd, AddressVerificationCondition addressVerificationCondition = AddressVerificationCondition.keyed})
const
TransactionConfiguration.fastCardPresent({bool emvAllowed = true, bool quickChipAllowed = true, bool duplicateTransactionsAllowed = true, bool partialApprovalAllowed = false, bool feeAssistEnabled = false, bool proceedWithoutSurchargeOnError = false, bool shouldConfirmSurchargeAmount = false, CurrencyCode currencyCode = CurrencyCode.usd, AddressVerificationCondition addressVerificationCondition = AddressVerificationCondition.keyed})
factory

Properties

addressVerificationCondition AddressVerificationCondition
Address verification condition
final
amountConfirmationEnabled bool
Enable amount confirmation
final
cashbackAllowed bool
Allow cashback
final
cashbackEntryAllowed bool
Allow cashback entry
final
cashbackEntryIncrement int
Cashback entry increment
final
cashbackEntryMaximum int
Maximum cashback amount
final
cashbackOptions List<double>
Cashback options
final
currencyCode CurrencyCode
Currency code
final
debitAllowed bool
Allow debit transactions
final
duplicateTransactionsAllowed bool
Enable duplicate transaction check
final
emvAllowed bool
Allow EMV transactions
final
feeAssistEnabled bool
Enable Worldpay Fee Assist hosted surcharge inquiry.
final
giftCardAllowed bool
Allow gift card transactions
final
hashCode int
The hash code for this object.
no setterinherited
partialApprovalAllowed bool
Allow partial approval
final
proceedWithoutSurchargeOnError bool
Continue the transaction without surcharge when surcharge inquiry fails.
final
quickChipAllowed bool
Allow Quick Chip
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldConfirmSurchargeAmount bool
Ask the cardholder to confirm the surcharge amount before continuing.
final
tipAllowed bool
Allow tips
final
tipEntryAllowed bool
Allow tip entry
final
tipOptions List<double>
Tip options (amounts or percentages)
final
tipSelectionType TipSelectionType
Tip selection type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited