shouldConfirmSurchargeAmount property
Ask the cardholder to confirm the surcharge amount before continuing.
Implementation
final bool shouldConfirmSurchargeAmount;
Ask the cardholder to confirm the surcharge amount before continuing.
final bool shouldConfirmSurchargeAmount;