DeviceInteractionRequest class
Constructors
-
DeviceInteractionRequest({required String requestId, required DeviceInteractionKind kind, String? title, List<
String> options = const [], String? amount, Map<String, dynamic> metadata = const {}}) -
const
-
DeviceInteractionRequest.fromMap(Map<
String, dynamic> map) -
factory
Properties
- amount → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → DeviceInteractionKind
-
final
-
metadata
→ Map<
String, dynamic> -
final
-
options
→ List<
String> -
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited