PaymentProcessor enum

支付处理器

Inheritance
Available extensions

Values

worldpay → const PaymentProcessor

Worldpay

worldpayCanada → const PaymentProcessor

Worldpay Canada

worldpayUk → const PaymentProcessor

Worldpay UK

worldpayRoi → const PaymentProcessor

Worldpay ROI

chasePaymentech → const PaymentProcessor

Chase Paymentech

firstData → const PaymentProcessor

First Data

tsys → const PaymentProcessor

TSYS

global → const PaymentProcessor

Global

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PaymentProcessor>
A constant List of the values in this enum, in order of their declaration.