TransactionStoringMode enum

离线交易存储模式(Store-and-Forward)

Inheritance
Available extensions

Values

auto → const TransactionStoringMode

自动模式:优先在线处理,网络不可用时自动转为离线存储

manual → const TransactionStoringMode

手动模式:固定走离线存储,不尝试在线授权

disabled → const TransactionStoringMode

禁用离线存储:必须在线处理,离线时交易失败

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TransactionStoringMode>
A constant List of the values in this enum, in order of their declaration.