FirmwareUpdateEvent class

Constructors

FirmwareUpdateEvent({required FirmwareUpdateSource source, required FirmwareUpdatePhase phase, required bool isBlockingUi, required bool isTerminal, FirmwareUpdateType updateType = FirmwareUpdateType.unknown, String? statusCode, String? description, double? progressPercent, Object? rawProgress, Map<String, dynamic> deviceInfo = const <String, dynamic>{}, Map<String, dynamic> rawData = const <String, dynamic>{}})
const
FirmwareUpdateEvent.fromMap(Map<String, dynamic> map)
factory
FirmwareUpdateEvent.unknown({Map<String, dynamic> rawData = const <String, dynamic>{}})
factory

Properties

description String?
final
deviceInfo Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
isBlockingUi bool
final
isTerminal bool
final
phase FirmwareUpdatePhase
final
progressPercent double?
final
rawData Map<String, dynamic>
final
rawProgress Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source FirmwareUpdateSource
final
statusCode String?
final
updateType FirmwareUpdateType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited