ConnectedBluetoothDeviceInfo class

已连接蓝牙设备信息

Constructors

ConnectedBluetoothDeviceInfo({String? name, required String macAddress, required String bondState, required String type, String? alias, int? bluetoothClass, List<String> sourceProfiles = const []})
const
ConnectedBluetoothDeviceInfo.fromMap(Map<String, dynamic> map)
factory

Properties

alias String?
final
bluetoothClass int?
final
bondState String
final
hashCode int
The hash code for this object.
no setterinherited
macAddress String
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceProfiles List<String>
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited