UsbDeviceEvent class

Event emitted when a supported Android USB payment reader is attached or detached.

Constructors

UsbDeviceEvent({required UsbDeviceEventType type, UsbDeviceInfo? device})
const
UsbDeviceEvent.fromMap(Map<String, dynamic> map)
factory

Properties

device UsbDeviceInfo?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type UsbDeviceEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited