UsbDeviceInfo class

Information about a supported USB payment reader attached to Android.

Detection is independent from triPOS initialization. An attached device is not ready for transactions until triPOS initialization succeeds.

Constructors

UsbDeviceInfo({required int deviceId, required String deviceName, required int vendorId, required int productId, String? manufacturerName, String? productName, String? serialNumber, required bool hasPermission})
const
UsbDeviceInfo.fromMap(Map<String, dynamic> map)
factory

Properties

deviceId int
final
deviceName String
final
hashCode int
The hash code for this object.
no setterinherited
hasPermission bool
final
manufacturerName String?
final
productId int
final
productName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String?
USB descriptor serial number, available only after Android USB access is granted and only when the reader firmware exposes it.
final
vendorId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited