firmwareUpdateEventChannel property
Event channel for firmware update and initialization progress events
Implementation
@visibleForTesting
final firmwareUpdateEventChannel = const EventChannel(
'tripos_mobile/firmware_update',
);
Event channel for firmware update and initialization progress events
@visibleForTesting
final firmwareUpdateEventChannel = const EventChannel(
'tripos_mobile/firmware_update',
);